is_self_field_shared_ref

Function is_self_field_shared_ref 

fn is_self_field_shared_ref(
    tcx: TyCtxt<'_>,
    caller: DefId,
    origin: &SelfFieldOrigin,
) -> Option<bool>
Check whether a self field’s type is a shared reference (&T or &[T]). Used by raw-ptr-deref alias checks to prove shared views are safe when the underlying field is a shared reference.